package io.hmit.controller;


import io.hmit.common.constant.Constant;
import io.hmit.common.page.PageData;
import io.hmit.annotation.LogOperation;
import io.hmit.common.utils.ConvertUtils;
import io.hmit.common.utils.Result;
import io.hmit.common.validator.AssertUtils;
import io.hmit.common.validator.ValidatorUtils;
import io.hmit.common.validator.group.AddGroup;
import io.hmit.common.validator.group.DefaultGroup;
import io.hmit.common.validator.group.UpdateGroup;
import io.hmit.dto.WlUploadInfoDTO;

import io.hmit.service.WlUploadInfoService;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiImplicitParam;
import io.swagger.annotations.ApiImplicitParams;
import io.swagger.annotations.ApiOperation;

import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;
import springfox.documentation.annotations.ApiIgnore;
import sun.net.www.content.text.plain;

import javax.servlet.http.HttpServletResponse;
import java.util.List;
import java.util.Map;


/**
 * 比赛人员信息
 *
 * @author zsh 408538940@qq.com
 * @since 1.0.0 2020-07-16
 */
@RestController
@RequestMapping("competition/wluploadinfo")
@Api(tags="比赛人员信息")
public class WlUploadInfoController {
    @Autowired
    private WlUploadInfoService wlUploadInfoService;

    @GetMapping("page")
    @ApiOperation("分页")
    @ApiImplicitParams({
        @ApiImplicitParam(name = Constant.PAGE, value = "当前页码，从1开始", paramType = "query", required = true, dataType="int") ,
        @ApiImplicitParam(name = Constant.LIMIT, value = "每页显示记录数", paramType = "query",required = true, dataType="int") ,
        @ApiImplicitParam(name = Constant.ORDER_FIELD, value = "排序字段", paramType = "query", dataType="String") ,
        @ApiImplicitParam(name = Constant.ORDER, value = "排序方式，可选值(asc、desc)", paramType = "query", dataType="String")
    })

    public Result<PageData<WlUploadInfoDTO>> page(@ApiIgnore @RequestParam Map<String, Object> params){
        PageData<WlUploadInfoDTO> page = wlUploadInfoService.page(params);

        return new Result<PageData<WlUploadInfoDTO>>().ok(page);
    }

    @GetMapping("{id}")
    @ApiOperation("信息")

    public Result<WlUploadInfoDTO> get(@PathVariable("id") Long id){
        WlUploadInfoDTO data = wlUploadInfoService.get(id);

        return new Result<WlUploadInfoDTO>().ok(data);
    }

/*
    @RequestParam 注解,默认 content-type:application/x-www-form-urlencoded;charset=UTF-8;
    当Content-Type：只限于三个值application/x-www-form-urlencoded、multipart/form-data、text/plain
    时,为简单请求,不会出现跨域的Option问题
*/
    @PostMapping
    @ApiOperation("保存")
    @LogOperation("保存")
    //@RequiresPermissions("competition:wluploadinfo:save")
    public Result save(@RequestParam Map<String, String> params){

        WlUploadInfoDTO dto = new WlUploadInfoDTO().assembleWluploadInfo(params);

        boolean flag = wlUploadInfoService.isName(dto.getName());
        if(flag){
            wlUploadInfoService.save(dto);
            return new Result();
        }else {
            return new Result().error(500,"人员信息已存在!");
        }

    }


/*
    最后使用版本
    前端使用json格式传输数据，SpringBoot @RequestBody 注解,默认只接收前端使用json进行传输
            content-type:application/json;charset=UTF-8;
    解决跨域问题，配置cors，前端访问接口使用域名访问，而不是IP+端口的形式

*/
    @PostMapping("/bodySave")
    @ApiOperation("保存")
    @LogOperation("保存")
    //@RequiresPermissions("competition:wluploadinfo:save")
    public Result save(@RequestBody WlUploadInfoDTO dto){
        //校验数据
        ValidatorUtils.validateEntity(dto, AddGroup.class, DefaultGroup.class);
        boolean flag = wlUploadInfoService.isName(dto.getName());
        if(flag){
            wlUploadInfoService.save(dto);
            return new Result();
        }else {
            return new Result().error(500,"人员信息已存在!");
        }

    }


    @PutMapping
    @ApiOperation("修改")

    public Result update(@RequestBody WlUploadInfoDTO dto){
        //校验数据
        ValidatorUtils.validateEntity(dto, UpdateGroup.class, DefaultGroup.class);

        wlUploadInfoService.update(dto);

        return new Result();
    }

    @DeleteMapping
    @ApiOperation("删除")

    public Result delete(@RequestBody Long[] ids){
        //校验数据
        AssertUtils.isArrayEmpty(ids, "id");

        wlUploadInfoService.delete(ids);

        return new Result();
    }



}
